@@ -98,7 +98,8 @@ class DataCounterResetter(QtGui.QWidget):
         
         self.typePicker = QtGui.QComboBox()
         self.typePicker.addItem(alarm_type)
-        self.typePicker.addItem(dbus_type)
+        ## removed until fixed in pymaemo!
+        #~ self.typePicker.addItem(dbus_type)
         self.typePicker.addItem(exec_type)
         self.typePicker.addItem(builtin_type)
         self.connect(self.typePicker, QtCore.SIGNAL("activated(int)"),
@@ -504,7 +505,9 @@ class DataCounterResetter(QtGui.QWidget):
             action = event.add_actions(1)[0]
             action.flags |= (alarm.ACTION_WHEN_TRIGGERED | 
                              alarm.ACTION_TYPE_EXEC)
-            action.command = str(eventInfo["content"])
+            action_string = str(eventInfo["content"]).replace("'","'\\''")
+            action_string = "/bin/ash -c '" + action_string + "'"
+            action.command = action_string
             
         elif eventInfo["type"] == builtin_type:
             action = event.add_actions(1)[0]
